/****************************************************************************
** Meta object code from reading C++ file 'bearerinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.28.0/src/dbus/bearerinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bearerinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN42OrgFreedesktopModemManager1BearerInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopModemManager1BearerInterface::qt_create_metaobjectdata<qt_meta_tag_ZN42OrgFreedesktopModemManager1BearerInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopModemManager1BearerInterface",
        "Connect",
        "QDBusPendingReply<>",
        "",
        "Disconnect",
        "Connected",
        "ConnectionError",
        "ModemManager::ConnectionError",
        "Interface",
        "Ip4Config",
        "QVariantMap",
        "Ip6Config",
        "IpTimeout",
        "Multiplexed",
        "Properties",
        "BearerType",
        "ProfileId",
        "ReloadStatsSupported",
        "Stats",
        "Suspended"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Connect'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'Disconnect'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(4, 3, QMC::AccessPublic, 0x80000000 | 2),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Connected'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'ConnectionError'
        QtMocHelpers::PropertyData<ModemManager::ConnectionError>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Interface'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Ip4Config'
        QtMocHelpers::PropertyData<QVariantMap>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Ip6Config'
        QtMocHelpers::PropertyData<QVariantMap>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'IpTimeout'
        QtMocHelpers::PropertyData<uint>(12, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Multiplexed'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Properties'
        QtMocHelpers::PropertyData<QVariantMap>(14, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'BearerType'
        QtMocHelpers::PropertyData<uint>(15, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'ProfileId'
        QtMocHelpers::PropertyData<uint>(16, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'ReloadStatsSupported'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Stats'
        QtMocHelpers::PropertyData<QVariantMap>(18, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Suspended'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopModemManager1BearerInterface, qt_meta_tag_ZN42OrgFreedesktopModemManager1BearerInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopModemManager1BearerInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopModemManager1BearerInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopModemManager1BearerInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN42OrgFreedesktopModemManager1BearerInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopModemManager1BearerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopModemManager1BearerInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->Connect();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->Disconnect();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::ConnectionError >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->connected(); break;
        case 1: *reinterpret_cast<ModemManager::ConnectionError*>(_v) = _t->connectionError(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->interface(); break;
        case 3: *reinterpret_cast<QVariantMap*>(_v) = _t->ip4Config(); break;
        case 4: *reinterpret_cast<QVariantMap*>(_v) = _t->ip6Config(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->ipTimeout(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->multiplexed(); break;
        case 7: *reinterpret_cast<QVariantMap*>(_v) = _t->properties(); break;
        case 8: *reinterpret_cast<uint*>(_v) = _t->bearerType(); break;
        case 9: *reinterpret_cast<uint*>(_v) = _t->profileId(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->reloadStatsSupported(); break;
        case 11: *reinterpret_cast<QVariantMap*>(_v) = _t->stats(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->suspended(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopModemManager1BearerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopModemManager1BearerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopModemManager1BearerInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopModemManager1BearerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
